@@ -1,7 +1,7 @@
 import socket
 import random
 from pprint import pformat
-from errno import EAGAIN
+from errno import EAGAIN, EWOULDBLOCK
 from Queue import Queue
 from Queue import Empty as QueueEmpty
 
@@ -267,7 +267,7 @@ class Frame(object):
                 try:
                     partial = self.sock.recv(1)
                 except socket.error, exc:
-                    if exc[0] == EAGAIN:
+                    if exc[0] == EAGAIN or exc[0] == EWOULDBLOCK:
                         if not buffer or buffer == '\n':
                             return None
                         continue
